# Changelog

<!--next-version-placeholder-->

## v1.4.0 (2022-07-17)
### Feature
* Strip obsidian comments ([`78dce9f`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/78dce9f8b73721121b08d95c0297ec7574cdb7aa))

## v1.3.8 (2022-07-16)
### Fix
* Add upper to everything so text searching ignore case ([`965ca31`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/965ca317380d1f2b43ad9d9a4eb3d188c54843f4))

## v1.3.7 (2022-07-16)


## v1.3.6 (2022-07-16)
### Fix
* In some condition, internal links were broke ([`6ed9c32`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/6ed9c32a6e3c678541f10e17486e165d4cd5321f))

## v1.3.5 (2022-07-16)


## v1.3.4 (2022-07-16)


## v1.3.3 (2022-07-16)


## v1.3.2 (2022-07-16)


## v1.3.1 (2022-07-16)


## v1.3.0 (2022-07-14)
### Feature
* Support of callouts+custom attributes ([`3d6fc0a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/3d6fc0a65313023fae1bfcd856e76a461f158d43))

## v1.2.13 (2022-07-13)


## v1.2.12 (2022-07-13)
### Fix
* Relative links not embedded correctly ([`c1a50ad`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/c1a50ad6a61fa1aa0842f55e0d4192c82aca3e08))

## v1.2.11 (2022-06-23)
### Fix
* Plugin broke with last update ([`855b377`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/855b377f698ae17c83ce4e6bf4b6104ad4275a6b))

## v1.2.10 (2022-06-19)
### Fix
* Prettify broke plugin ([`bde7ded`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/bde7ded9c605c9652264b62fcd4c587ab84e4ce3))

## v1.2.9 (2022-04-01)
### Fix
* Links in embed generation ([`204b6d7`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/204b6d70b31da1df3c6407d9f8f2f933e626dff3))

## v1.2.8 (2022-04-01)
### Fix
* HTTPS: // removed ([`a210d87`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/a210d870f30911bccdac731924c12d4707eb54b6))

## v1.2.7 (2022-03-30)
### Fix
* Remove print ([`2cb9a58`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/2cb9a5853b8205e245fadf4ed3f9b453cce5c408))

## v1.2.6 (2022-03-30)
### Fix
* URL generation ([`0dac1a5`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/0dac1a526a8ff2141b15bb29f819afb0d22f2516))

## v1.2.5 (2022-03-23)


## v1.2.4 (2022-03-23)


## v1.2.3 (2022-03-23)
### Fix
* Requirements ([`76582a6`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/76582a6d0ef6c61cb3ffe0062c2ed50ca4e2b621))

## v1.2.2 (2022-03-22)


## v1.2.4 (2022-03-22)


## v1.2.3 (2022-03-22)


## v1.2.2 (2022-03-22)


## v1.2.2 (2022-03-22)


## v1.2.2 (2022-03-22)


## v1.2.3 (2022-03-22)


## v1.2.2 (2022-03-22)


## v1.2.3 (2022-03-22)


## v1.2.2 (2022-03-22)


## v1.2.1 (2022-03-22)
### Fix
* Wikilinks in embed with shortpath ([`6b0de80`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/6b0de8079f4ad468a503a9512101ec333e08ac1b))

### Documentation
*  update demo ([`d68581f`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/d68581f16730fe6d67ecd85000fc3cbe75f57c9e))

## v1.2.0 (2022-03-22)
### Feature
* Update requirements to support image ([`b2357ef`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/b2357ef6796d936fe63f0b9c8d9f4e827f4370e2))

## v1.1.0 (2022-03-21)
### Feature
*  minimal support for wikilinks ([`20abfc6`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/20abfc60b23de98634bccb1f62383e08db0610b1))

## v1.0.5 (2022-03-20)
### Fix
* Requirements ([`48fc904`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/48fc904c4f8474ce8017d8bb460a51760c8b308e))

## v1.0.4 (2022-03-20)
### Fix
* Always get alt or do nothing ([`53987eb`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/53987eb9ce8d72961d7b7fee3bdc444acdc32f41))
* Fix blog build if alt not found in link ([`3c51807`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/3c5180775fdf3bc9306806c7786600b939feffd2))
* Revert files error ([`1065c1a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/1065c1a7c98b19e3b7b6fcf36878271013b6e993))
* Fix requirements & build because of the new https change ([`674b6df`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/674b6df4e5e05bf038f969dbaf31f95ab624f39c))

### Documentation
* **readme:** Add demo gif ([`c13137d`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/c13137dbf59ac9874ca911c555870101c4c7b7fb))

## v1.0.3 (2022-01-20)
### Fix
* Adjust link generation ([`001d6e9`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/001d6e92a4f6556004382bb841b3b13c298dfda6))

### Documentation
* **gitignore:** Exclude build ([`80da76b`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/80da76b7f2f2433a154db5b41aed522de197e0bc))

## v1.0.2 (2022-01-20)
### Fix
* **extension:** Add extension to parse markdown in embed files ([`5dfac7a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/5dfac7a793cb03c27ebd406db42042f413c2ae32))

### Documentation
* **readme:** Update readme ([`84dc575`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/84dc575bce22560f69fbdb7e8d00f2f92ca0f222))
* **readme:** Fix typo ([`a48b56a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/a48b56a855dafca67172d120b14036e9ede1745d))
* **readme:** Add screenshot ([`307fbb1`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/307fbb12cb87ec6cdefac4b6bf9dfb737b399e1d))

## v1.0.1 (2022-01-20)
### Fix
* Fix all contents citation ([`a5a21b6`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/a5a21b6efda0b44c09aa9b16d5db4c9106c2780b))

## v1.0.0 (2022-01-20)
### Feature
* **commit:** First commit ([`0ef98d3`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/0ef98d3b1141c8a05a03133fd764de2160b0a288))

### Breaking
* First commit ([`0ef98d3`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/0ef98d3b1141c8a05a03133fd764de2160b0a288))

### Documentation
* **css:** Add css example ([`85ceba1`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/85ceba1ae6240b016f7947790ab41d7cafae6f85))
* **gitignore:** Add idea and test ([`d1d3e83`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/d1d3e83954491b962c9736f6fca35ea31c2bc7c0))
* **readme:** Add readme ([`28d395f`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/28d395f76f27ccc2a0de10c0d96f00cf16ceac35))
* **readme:** Update readme ([`04fee26`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/04fee26e291f30337e5e3af52aa3b400cfbf1d0a))
